@@ -2,17 +2,14 @@
 package noris::Date::Calendar::Profiles;
 
 use strict;
-# kein UTF-8 - Datei latin1 codiert lassen
-# da die originallen Profile auf lati1 sind und Perl beim den HashKeys
-# sonst durcheinander kommt
-#use utf8;
+use utf8;
 use vars qw( @ISA @EXPORT @EXPORT_OK $VERSION $Profiles );
 
 require Exporter;
 @ISA       = qw(Exporter);
 @EXPORT    = qw();
 @EXPORT_OK = qw( $Profiles );
-$VERSION   = '0.2';
+$VERSION   = '0.4';
 
 use Date::Calendar::Profiles;    # depends: libdate-calc-perl
 $Profiles = $Date::Calendar::Profiles::Profiles;
@@ -21,7 +18,7 @@ $Profiles->{'DE-BY-noris'} = {    # noris Kalender
     "Nikolaus"          => "#06.12.",
     "Heiligabend"       => ":24.12.",
     "Sylvester"         => ":31.12.",
-    "Mari Himmelfahrt" => "#15.08.",
+    "Mari\xE4 Himmelfahrt" => "#15.08.",
 };
 
 1;
@@ -43,7 +40,7 @@ Nachdem das offiziele Paket bestimmte Feiertage bzw. halbe Tage nicht als
 solche wertet, haben wir unseren eigenen Kalender erzeugt. Dieser behebt
 die "Fehler" des Original Pakets
 
-=head1 RCKGABEWERT
+=head1 RÜCKGABEWERT
 
 Hashref $Profiles mit den Feiertagen wird exportiert.
 
